import { defineStore } from 'pinia'
import { ref } from 'vue'

type AccessToken = null | string
const initState = {
  access_codes: [],
  access_menus: [],
  access_routes: [],
  access_token: null,
  is_access_checked: false,
  login_expired: false,
  refresh_token: null,
}

interface AccessInfo {
  /**
   * 权限码
   */
  access_codes: string[]
  /**
   * 可访问的菜单列表
   */
  access_menus: string[]
  /**
   * 可访问的路由列表
   */
  access_routes: string[]
  /**
   * 登录 accessToken
   */
  access_token: AccessToken
  /**
   * 是否已经检查过权限
   */
  is_access_checked: boolean
  /**
   * 登录是否过期
   */
  login_expired: boolean
  /**
   * 登录 accessToken
   */
  refresh_token: AccessToken
}

export const useAccessStore = defineStore(
  'accessInfo',
  () => {
    const accessInfo = ref<AccessInfo>({ ...initState })

    const setAccessInfo = (val: AccessInfo) => {
      accessInfo.value = val
    }
    const setAccessToken = (val: AccessToken) => {
      accessInfo.value.access_token = val
    }

    const clearAccessInfo = () => {
      accessInfo.value = { ...initState }
    }
    // 一般没有reset需求，不需要的可以删除
    const reset = () => {
      accessInfo.value = { ...initState }
    }
    const isLogined = computed(() => !!accessInfo.value.access_token)

    return {
      accessInfo,
      setAccessInfo,
      setAccessToken,
      clearAccessInfo,
      isLogined,
      reset,
    }
  },
  {
    persist: true,
  },
)
